@@ -100,7 +100,7 @@ def build_cache():
     )
 
     # We grab Gohlke's code and evaluate it within py2js
-    dl_function = re.search(r"function dl.*\}", soup.find("script").text).group(0)
+    dl_function = re.search(r"function dl.*\}", soup.find("script").string).group(0)
     context.execute(dl_function)
 
     links = soup.find(class_="pylibs").find_all("a")
